@@ -41,11 +41,6 @@ var proxiedFunctionTable = ["null" /* Reserve index 0 for an undefined function*
 // map: pair(sig, syncOrAsync) -> function body
 var proxiedFunctionInvokers = {};
 
-// We include asm2wasm imports if the trap mode is 'js' (to call out to JS to do some math stuff).
-// However, we always need some of them (like the frem import because % is in asm.js but not in wasm).
-// But we can avoid emitting all the others in many cases.
-var NEED_ALL_ASM2WASM_IMPORTS = BINARYEN_TRAP_MODE == 'js';
-
 // Used internally. set when there is a main() function.
 // Also set when in a linkable module, as the main() function might
 // arrive from a dynamically-linked library, and not necessarily
@@ -54,8 +49,6 @@ var NEED_ALL_ASM2WASM_IMPORTS = BINARYEN_TRAP_MODE == 'js';
 // static ctors, even if there is no user main.
 var HAS_MAIN = ('_main' in IMPLEMENTED_FUNCTIONS) || MAIN_MODULE || SIDE_MODULE || STANDALONE_WASM;
 
-WEAK_DECLARES = set(WEAK_DECLARES);
-
 // Mangles the given C/JS side function name to assembly level function name (adds an underscore)
 function mangleCSymbolName(f) {
   return f[0] == '$' ? f.substr(1) : '_' + f;
@@ -169,12 +162,12 @@ function JSify(data, functionsOnly) {
         usedExternPrimitives[ident] = 1;
         return;
       } else if ((!LibraryManager.library.hasOwnProperty(ident) && !LibraryManager.library.hasOwnProperty(ident + '__inline')) || SIDE_MODULE) {
-        if (!(finalName in IMPLEMENTED_FUNCTIONS) && !(finalName in WEAK_DECLARES) && !LINKABLE) {
+        if (!(finalName in IMPLEMENTED_FUNCTIONS) && !LINKABLE) {
           var msg = 'undefined symbol: ' + ident;
           if (dependent) msg += ' (referenced by ' + dependent + ')';
           if (ERROR_ON_UNDEFINED_SYMBOLS) {
             error(msg);
-            if (WASM_BACKEND && !LLD_REPORT_UNDEFINED) {
+            if (!LLD_REPORT_UNDEFINED) {
               warnOnce('Link with `-s LLD_REPORT_UNDEFINED` to get more information on undefined symbols');
             }
             warnOnce('To disable errors for undefined symbols use `-s ERROR_ON_UNDEFINED_SYMBOLS=0`')
@@ -377,16 +370,6 @@ function JSify(data, functionsOnly) {
 
     itemsDict.functionStub.push(item);
     var shortident = demangleCSymbolName(item.ident);
-    // If this is not linkable, anything not in the library is definitely missing
-    if (item.ident in DEAD_FUNCTIONS) {
-      if (LibraryManager.library[shortident + '__asm']) {
-        warn('cannot kill asm library function ' + item.ident);
-      } else {
-        LibraryManager.library[shortident] = new Function("err('dead function: " + shortident + "'); abort(-1);");
-        delete LibraryManager.library[shortident + '__inline'];
-        delete LibraryManager.library[shortident + '__deps'];
-      }
-    }
     item.JS = addFromLibrary(shortident, 'top-level compiled C/C++ code');
   }
 
@@ -467,33 +450,6 @@ function JSify(data, functionsOnly) {
         print('/* no memory initializer */'); // test purposes
       }
 
-      if (!SIDE_MODULE && !WASM_BACKEND) {
-        if (USE_PTHREADS) {
-          print('// Pthreads fill their tempDoublePtr memory area into the pthread stack when the thread is run.')
-          // Main thread still statically allocate tempDoublePtr - although it could theorerically also use its stack
-          // (that might allow removing the whole tempDoublePtr variable altogether from the codebase? but would need
-          // more refactoring)
-          print('var tempDoublePtr = ENVIRONMENT_IS_PTHREAD ? 0 : ' + makeStaticAlloc(8) + ';');
-        } else {
-          print('var tempDoublePtr = ' + makeStaticAlloc(8) + ';');
-        }
-        print('\nfunction copyTempFloat(ptr) { // functions, because inlining this code increases code size too much');
-        print('  HEAP8[tempDoublePtr] = HEAP8[ptr];');
-        print('  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];');
-        print('  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];');
-        print('  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];');
-        print('}\n');
-        print('function copyTempDouble(ptr) {');
-        print('  HEAP8[tempDoublePtr] = HEAP8[ptr];');
-        print('  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];');
-        print('  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];');
-        print('  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];');
-        print('  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];');
-        print('  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];');
-        print('  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];');
-        print('  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];');
-        print('}\n');
-      }
       print('// {{PRE_LIBRARY}}\n'); // safe to put stuff here that statically allocates
 
       return;
