@@ -9,7 +9,6 @@ var LibraryPThreadStub = {
   // Stub implementation for pthread.h when not compiling with pthreads support enabled.
   // ===================================================================================
 
-#if ENVIRONMENT_MAY_BE_WORKER || WASM_BACKEND
   emscripten_is_main_browser_thread: function() {
 #if MINIMAL_RUNTIME
     return typeof importScripts === 'undefined';
@@ -17,13 +16,6 @@ var LibraryPThreadStub = {
     return !ENVIRONMENT_IS_WORKER;
 #endif
   },
-#else
-  emscripten_is_main_browser_thread__asm: true,
-  emscripten_is_main_browser_thread__sig: 'i',
-  emscripten_is_main_browser_thread: function() {
-    return 1;
-  },
-#endif
 
   pthread_mutexattr_init: function() {},
   pthread_mutexattr_setschedparam: function() {},
