@@ -161,15 +161,4 @@ var WasiLibrary = {
   },
 };
 
-// Fallback for cases where the wasi_interface_version.name prefixing fails,
-// and we have the full name from C. This happens in fastcomp which
-// lacks the attribute to set the import module and base names.
-if (!WASM_BACKEND) {
-  for (var x in WasiLibrary) {
-    if (isJsLibraryConfigIdentifier(x)) continue;
-    if (isJsOnlyIdentifier(x)) continue;
-    WasiLibrary['__wasi_' + x] = x;
-  }
-}
-
 mergeInto(LibraryManager.library, WasiLibrary);
