@@ -1,3 +1,9 @@
+/**
+ * @license
+ * Copyright 2019 The Emscripten Authors
+ * SPDX-License-Identifier: MIT
+ */
+
 #if SAFE_HEAP || !MINIMAL_RUNTIME
 // In MINIMAL_RUNTIME, setValue() and getValue() are only available when building with safe heap enabled, for heap safety checking.
 // In traditional runtime, setValue() and getValue() are always available (although their use is highly discouraged due to perf penalties)
@@ -94,12 +100,15 @@ var SAFE_HEAP_COUNTER = 0;
 
 /** @param {number|boolean=} isFloat */
 function SAFE_HEAP_STORE(dest, value, bytes, isFloat) {
+#if CAN_ADDRESS_2GB
+  dest >>>= 0;
+#endif
 #if SAFE_HEAP_LOG
   out('SAFE_HEAP store: ' + [dest, value, bytes, isFloat, SAFE_HEAP_COUNTER++]);
 #endif
   if (dest <= 0) abort('segmentation fault storing ' + bytes + ' bytes to address ' + dest);
   if (dest % bytes !== 0) abort('alignment error storing to address ' + dest + ', which was expected to be aligned to a multiple of ' + bytes);
-  if (dest + bytes > HEAP32[DYNAMICTOP_PTR>>2]) abort('segmentation fault, exceeded the top of the available dynamic heap when storing ' + bytes + ' bytes to address ' + dest + '. DYNAMICTOP=' + HEAP32[DYNAMICTOP_PTR>>2]);
+  if (dest + bytes > HEAPU32[DYNAMICTOP_PTR>>2]) abort('segmentation fault, exceeded the top of the available dynamic heap when storing ' + bytes + ' bytes to address ' + dest + '. DYNAMICTOP=' + HEAP32[DYNAMICTOP_PTR>>2]);
   assert(DYNAMICTOP_PTR);
   assert(HEAP32[DYNAMICTOP_PTR>>2] <= HEAP8.length);
   setValue(dest, value, getSafeHeapType(bytes, isFloat), 1);
@@ -110,9 +119,12 @@ function SAFE_HEAP_STORE_D(dest, value, bytes) {
 
 /** @param {number|boolean=} isFloat */
 function SAFE_HEAP_LOAD(dest, bytes, unsigned, isFloat) {
+#if CAN_ADDRESS_2GB
+  dest >>>= 0;
+#endif
   if (dest <= 0) abort('segmentation fault loading ' + bytes + ' bytes from address ' + dest);
   if (dest % bytes !== 0) abort('alignment error loading from address ' + dest + ', which was expected to be aligned to a multiple of ' + bytes);
-  if (dest + bytes > HEAP32[DYNAMICTOP_PTR>>2]) abort('segmentation fault, exceeded the top of the available dynamic heap when loading ' + bytes + ' bytes from address ' + dest + '. DYNAMICTOP=' + HEAP32[DYNAMICTOP_PTR>>2]);
+  if (dest + bytes > HEAPU32[DYNAMICTOP_PTR>>2]) abort('segmentation fault, exceeded the top of the available dynamic heap when loading ' + bytes + ' bytes from address ' + dest + '. DYNAMICTOP=' + HEAP32[DYNAMICTOP_PTR>>2]);
   assert(DYNAMICTOP_PTR);
   assert(HEAP32[DYNAMICTOP_PTR>>2] <= HEAP8.length);
   var type = getSafeHeapType(bytes, isFloat);
@@ -145,3 +157,91 @@ function ftfault() {
   abort('Function table mask error');
 }
 #endif
+
+#if USE_ASAN
+// C versions of asan_js_{load|store}_* will be used from compiled code, which have
+// ASan instrumentation on them. However, until the wasm module is ready, we
+// must access things directly.
+
+/** @suppress{duplicate} */
+function _asan_js_load_1(ptr) {
+  if (runtimeInitialized) return _asan_c_load_1(ptr);
+  return HEAP8[ptr];
+}
+/** @suppress{duplicate} */
+function _asan_js_load_1u(ptr) {
+  if (runtimeInitialized) return _asan_c_load_1u(ptr);
+  return HEAPU8[ptr];
+}
+/** @suppress{duplicate} */
+function _asan_js_load_2(ptr) {
+  if (runtimeInitialized) return _asan_c_load_2(ptr);
+  return HEAP16[ptr];
+}
+/** @suppress{duplicate} */
+function _asan_js_load_2u(ptr) {
+  if (runtimeInitialized) return _asan_c_load_2u(ptr);
+  return HEAPU16[ptr];
+}
+/** @suppress{duplicate} */
+function _asan_js_load_4(ptr) {
+  if (runtimeInitialized) return _asan_c_load_4(ptr);
+  return HEAP32[ptr];
+}
+/** @suppress{duplicate} */
+function _asan_js_load_4u(ptr) {
+  if (runtimeInitialized) return _asan_c_load_4u(ptr) >>> 0;
+  return HEAPU32[ptr];
+}
+/** @suppress{duplicate} */
+function _asan_js_load_f(ptr) {
+  if (runtimeInitialized) return _asan_c_load_f(ptr);
+  return HEAPF32[ptr];
+}
+/** @suppress{duplicate} */
+function _asan_js_load_d(ptr) {
+  if (runtimeInitialized) return _asan_c_load_d(ptr);
+  return HEAPF64[ptr];
+}
+
+/** @suppress{duplicate} */
+function _asan_js_store_1(ptr, val) {
+  if (runtimeInitialized) return _asan_c_store_1(ptr, val);
+  return HEAP8[ptr] = val;
+}
+/** @suppress{duplicate} */
+function _asan_js_store_1u(ptr, val) {
+  if (runtimeInitialized) return _asan_c_store_1u(ptr, val);
+  return HEAPU8[ptr] = val;
+}
+/** @suppress{duplicate} */
+function _asan_js_store_2(ptr, val) {
+  if (runtimeInitialized) return _asan_c_store_2(ptr, val);
+  return HEAP16[ptr] = val;
+}
+/** @suppress{duplicate} */
+function _asan_js_store_2u(ptr, val) {
+  if (runtimeInitialized) return _asan_c_store_2u(ptr, val);
+  return HEAPU16[ptr] = val;
+}
+/** @suppress{duplicate} */
+function _asan_js_store_4(ptr, val) {
+  if (runtimeInitialized) return _asan_c_store_4(ptr, val);
+  return HEAP32[ptr] = val;
+}
+/** @suppress{duplicate} */
+function _asan_js_store_4u(ptr, val) {
+  if (runtimeInitialized) return _asan_c_store_4u(ptr, val) >>> 0;
+  return HEAPU32[ptr] = val;
+}
+/** @suppress{duplicate} */
+function _asan_js_store_f(ptr, val) {
+  if (runtimeInitialized) return _asan_c_store_f(ptr, val);
+  return HEAPF32[ptr] = val;
+}
+/** @suppress{duplicate} */
+function _asan_js_store_d(ptr, val) {
+  if (runtimeInitialized) return _asan_c_store_d(ptr, val);
+  return HEAPF64[ptr] = val;
+}
+#endif
