@@ -69,9 +69,6 @@ if (ENVIRONMENT_IS_NODE) {
 #endif
 #endif
 #else
-#if SEPARATE_ASM
-  eval(fs.readFileSync(__dirname + '/{{{ TARGET_BASENAME }}}.asm.js')+'');
-#endif
 #endif
 #if MEM_INIT_METHOD == 1 && !MEM_INIT_IN_WASM
   Module['mem'] = fs.readFileSync(__dirname + '/{{{ TARGET_BASENAME }}}.mem');
@@ -99,32 +96,6 @@ if (ENVIRONMENT_IS_SHELL) {
 }
 #endif
 
-#if !WASM && !WASM_BACKEND
-// asm.js loading in fastcomp backend:
-
-#if ENVIRONMENT_MAY_BE_NODE
-if (ENVIRONMENT_IS_NODE) {
-  var fs = require('fs');
-#if SEPARATE_ASM
-  eval(fs.readFileSync(__dirname + '/{{{ TARGET_BASENAME }}}.asm.js')+'');
-#endif
-#if MEM_INIT_METHOD == 1 && !MEM_INIT_IN_WASM
-  Module['mem'] = fs.readFileSync(__dirname + '/{{{ TARGET_BASENAME }}}.mem');
-#endif
-}
-#endif
-
-#if ENVIRONMENT_MAY_BE_SHELL
-if (ENVIRONMENT_IS_SHELL) {
-  eval(read('{{{ TARGET_BASENAME }}}.asm.js')+'');
-#if MEM_INIT_METHOD == 1 && !MEM_INIT_IN_WASM
-  Module['mem'] = read('{{{ TARGET_BASENAME }}}.mem', 'binary');
-#endif
-}
-#endif
-
-#endif
-
 #endif // !SINGLE_FILE
 
 // Redefine these in a --pre-js to override behavior. If you would like to
