@@ -19,7 +19,7 @@ from runner import create_test_file, no_wasm_backend, ensure_dir
 from tools.shared import NODE_JS, PYTHON, EMCC, SPIDERMONKEY_ENGINE, V8_ENGINE
 from tools.shared import CONFIG_FILE, EM_CONFIG, LLVM_ROOT, CANONICAL_TEMP_DIR
 from tools.shared import try_delete
-from tools.shared import expected_llvm_version, Cache, Settings
+from tools.shared import EXPECTED_LLVM_VERSION, Cache
 from tools import shared, system_libs
 
 SANITY_FILE = shared.Cache.get_path('sanity.txt', root=True)
@@ -141,7 +141,6 @@ class sanity(RunnerCore):
     print()
 
     assert 'EMCC_DEBUG' not in os.environ, 'do not run sanity checks in debug mode!'
-    assert 'EMCC_WASM_BACKEND' not in os.environ, 'do not force wasm backend either way in sanity checks!'
 
   @classmethod
   def tearDownClass(cls):
@@ -200,7 +199,6 @@ class sanity(RunnerCore):
         temp_bin = tempfile.mkdtemp()
         make_executable('llvm-dis')
         make_executable('node')
-        make_executable('python2')
         env['PATH'] = temp_bin + os.pathsep + os.environ['PATH']
         output = self.do(command, env=env)
       finally:
@@ -266,12 +264,9 @@ class sanity(RunnerCore):
     with open(CONFIG_FILE, 'a') as f:
       f.write('LLVM_ROOT = "' + self.in_dir('fake') + '"')
 
-    real_version_x, real_version_y = (int(x) for x in expected_llvm_version().split('.'))
-    if shared.get_llvm_target() == shared.WASM_TARGET:
-      make_fake_llc(self.in_dir('fake', 'llc'), 'wasm32 - WebAssembly 32-bit')
-      make_fake_lld(self.in_dir('fake', 'wasm-ld'))
-    else:
-      make_fake_llc(self.in_dir('fake', 'llc'), 'js - JavaScript (asm.js, emscripten)')
+    real_version_x, real_version_y = (int(x) for x in EXPECTED_LLVM_VERSION.split('.'))
+    make_fake_llc(self.in_dir('fake', 'llc'), 'wasm32 - WebAssembly 32-bit')
+    make_fake_lld(self.in_dir('fake', 'wasm-ld'))
 
     with env_modify({'EM_IGNORE_SANITY': '1'}):
       for inc_x in range(-2, 3):
@@ -300,32 +295,6 @@ class sanity(RunnerCore):
     add_to_config("EMSCRIPTEN_ROOT = '%s'" % (path_from_root() + os.path.sep))
     self.check_working(EMCC)
 
-  def test_llvm_fastcomp(self):
-    WARNING = 'fastcomp in use, but LLVM has not been built with the JavaScript backend as a target'
-
-    restore_and_set_up()
-
-    # Should see js backend during sanity check
-    self.assertTrue(shared.check_llvm())
-    output = self.check_working(EMCC)
-    self.assertNotIn(WARNING, output)
-
-    # Fake incorrect llc output, no mention of js backend
-    restore_and_set_up()
-    with open(CONFIG_FILE, 'a') as f:
-      f.write('LLVM_ROOT = "' + self.in_dir('fake', 'bin') + '"')
-    # print '1', open(CONFIG_FILE).read()
-
-    make_fake_clang(self.in_dir('fake', 'bin', 'clang'), expected_llvm_version())
-    make_fake_llc(self.in_dir('fake', 'bin', 'llc'), 'no j-s backend for you!')
-    self.check_working(EMCC, WARNING)
-
-    # fake some more
-    for fake in ['llvm-link', 'llvm-ar', 'opt', 'llvm-as', 'llvm-dis', 'llvm-nm', 'lli']:
-      open(self.in_dir('fake', 'bin', fake), 'w').write('.')
-    try_delete(SANITY_FILE)
-    self.check_working(EMCC, WARNING)
-
   def test_node(self):
     NODE_WARNING = 'node version appears too old'
     NODE_WARNING_2 = 'cannot check node version'
@@ -462,7 +431,7 @@ fi
     for i in range(3):
       print(i)
       self.clear()
-      output = self.do([EMCC, '-O' + str(i), '-s', '--llvm-lto', '0', path_from_root('tests', 'hello_libcxx.cpp'), '-s', 'DISABLE_EXCEPTION_CATCHING=0'])
+      output = self.do([EMCC, '-O' + str(i), path_from_root('tests', 'hello_libcxx.cpp'), '-s', 'DISABLE_EXCEPTION_CATCHING=0'])
       print('\n\n\n', output)
       self.assertContainedIf(BUILDING_MESSAGE.replace('X', libname), output, i == 0)
       self.assertContained('hello, world!', self.run_js('a.out.js'))
@@ -485,7 +454,7 @@ fi
     # Changing LLVM_ROOT, even without altering .emscripten, clears the cache
     restore_and_set_up()
     self.ensure_cache()
-    make_fake_clang(self.in_dir('fake', 'bin', 'clang'), expected_llvm_version())
+    make_fake_clang(self.in_dir('fake', 'bin', 'clang'), EXPECTED_LLVM_VERSION)
     make_fake_llc(self.in_dir('fake', 'bin', 'llc'), 'got wasm32 backend! WebAssembly 32-bit')
     with env_modify({'EM_LLVM_ROOT': self.in_dir('fake', 'bin')}):
       self.assertTrue(os.path.exists(Cache.dirname))
@@ -537,10 +506,7 @@ fi
     # The cache directory must exist after the build
     self.assertTrue(os.path.exists(cache_dir_name))
     # The cache directory must contain a built libc
-    if self.is_wasm_backend():
-      self.assertTrue(os.path.exists(os.path.join(cache_dir_name, 'wasm', 'libc.a')))
-    else:
-      self.assertTrue(os.path.exists(os.path.join(cache_dir_name, 'asmjs', 'libc.bc')))
+    self.assertTrue(os.path.exists(os.path.join(cache_dir_name, 'wasm', 'libc.a')))
     # Exactly one child process should have triggered libc build!
     self.assertEqual(num_times_libc_was_built, 1)
 
@@ -695,20 +661,6 @@ fi
     restore_and_set_up()
     Cache.erase()
 
-    with env_modify({'EMCC_DEBUG': '1'}):
-      # see that we test vanilla status, and just once
-      TESTING = 'testing for asm.js target'
-      print(self.check_working(EMCC, TESTING))
-
-      for i in range(3):
-        output = self.check_working(EMCC, 'check tells us to use')
-        self.assertNotContained(TESTING, output)
-      # if env var tells us, do what it says
-      with env_modify({'EMCC_WASM_BACKEND': '1'}):
-        self.check_working(EMCC, 'EMCC_WASM_BACKEND tells us to use wasm backend')
-      with env_modify({'EMCC_WASM_BACKEND': '0'}):
-        self.check_working(EMCC, 'EMCC_WASM_BACKEND tells us to use asm.js backend')
-
     def make_fake(report):
       with open(CONFIG_FILE, 'a') as f:
         f.write('LLVM_ROOT = "' + self.in_dir('fake', 'bin') + '"\n')
@@ -716,91 +668,19 @@ fi
         # doesn't actually use it.
         f.write('BINARYEN_ROOT= "%s"\n' % self.in_dir('fake', 'bin'))
 
-      make_fake_clang(self.in_dir('fake', 'bin', 'clang'), expected_llvm_version())
+      make_fake_clang(self.in_dir('fake', 'bin', 'clang'), EXPECTED_LLVM_VERSION)
       make_fake_llc(self.in_dir('fake', 'bin', 'llc'), report)
       make_fake_lld(self.in_dir('fake', 'bin', 'wasm-ld'))
 
-    with env_modify({'EMCC_DEBUG': '1'}):
-      make_fake('wasm32-unknown-unknown-elf')
-      # see that we request the right backend from llvm
-      with env_modify({'EMCC_WASM_BACKEND': '1'}):
-        self.check_working([EMCC] + MINIMAL_HELLO_WORLD + ['-c'], 'wasm32-unknown-unknown-elf')
-      make_fake('asmjs-unknown-emscripten')
-      with env_modify({'EMCC_WASM_BACKEND': '0'}):
-        self.check_working([EMCC] + MINIMAL_HELLO_WORLD + ['-c'], 'asmjs-unknown-emscripten')
-      # check the current installed one is ok
-      restore_and_set_up()
-      self.check_working(EMCC)
-      output = self.check_working(EMCC, 'check tells us to use')
-      if 'wasm backend' in output:
-        self.check_working([EMCC] + MINIMAL_HELLO_WORLD + ['-c'], 'wasm32-unknown-emscripten')
-      else:
-        assert 'asm.js backend' in output
-        self.check_working([EMCC] + MINIMAL_HELLO_WORLD + ['-c'], 'asmjs-unknown-emscripten')
-
     # fake llc output
 
     def test_with_fake(report, expected):
       make_fake(report)
       with env_modify({'EMCC_DEBUG': '1'}):
-        output = self.check_working([EMCC] + MINIMAL_HELLO_WORLD + ['-c'], expected)
-        self.assertContained('config file changed since we checked vanilla', output)
-
-    test_with_fake('got js backend! JavaScript (asm.js, emscripten) backend', 'check tells us to use asm.js backend')
-    test_with_fake('got wasm32 backend! WebAssembly 32-bit',                  'check tells us to use wasm backend')
-
-    # use LLVM env var to modify LLVM between vanilla checks
-
-    assert not os.environ.get('EM_LLVM_ROOT'), 'we need to modify EM_LLVM_ROOT env var for this'
-
-    f = open(CONFIG_FILE, 'a')
-    f.write('LLVM_ROOT = "' + self.in_dir('fake1', 'bin') + '"\n')
-    f.close()
-
-    ensure_dir(self.in_dir('fake1', 'bin'))
-    f = open(self.in_dir('fake1', 'bin', 'llc'), 'w')
-    f.write('#!/bin/sh\n')
-    f.write('echo "llc fake1 output\nRegistered Targets:\n%s"' % 'got js backend! JavaScript (asm.js, emscripten) backend')
-    f.close()
-    os.chmod(self.in_dir('fake1', 'bin', 'llc'), stat.S_IREAD | stat.S_IWRITE | stat.S_IEXEC)
-
-    ensure_dir(self.in_dir('fake2', 'bin'))
-    f = open(self.in_dir('fake2', 'bin', 'llc'), 'w')
-    f.write('#!/bin/sh\n')
-    f.write('echo "llc fake2 output\nRegistered Targets:\n%s"' % 'got wasm32 backend! WebAssembly 32-bit')
-    f.close()
-    os.chmod(self.in_dir('fake2', 'bin', 'llc'), stat.S_IREAD | stat.S_IWRITE | stat.S_IEXEC)
-
-    with env_modify({'EMCC_DEBUG': '1'}):
-      self.check_working([EMCC] + MINIMAL_HELLO_WORLD + ['-c'], 'use asm.js backend')
-      with env_modify({'EM_LLVM_ROOT': self.in_dir('fake2', 'bin')}):
-        self.check_working([EMCC] + MINIMAL_HELLO_WORLD + ['-c'], 'regenerating vanilla check since other llvm')
+        self.check_working([EMCC] + MINIMAL_HELLO_WORLD + ['-c'], expected)
 
+    test_with_fake('got js backend! JavaScript (asm.js, emscripten) backend', 'LLVM has not been built with the WebAssembly backend')
     try_delete(CANONICAL_TEMP_DIR)
-    return # TODO: the rest of this
-
-    # check separate cache dirs are used
-
-    restore_and_set_up()
-    self.check_working([EMCC], '')
-
-    root_cache = os.path.expanduser('~/.emscripten_cache')
-    if os.path.exists(os.path.join(root_cache, 'asmjs')):
-      shutil.rmtree(os.path.join(root_cache, 'asmjs'))
-    if os.path.exists(os.path.join(root_cache, 'wasm')):
-      shutil.rmtree(os.path.join(root_cache, 'wasm'))
-
-    with env_modify({'EMCC_WASM_BACKEND': '1'}):
-      self.check_working([EMCC] + MINIMAL_HELLO_WORLD, '')
-      self.assertExists(os.path.join(root_cache, 'wasm'))
-
-    with env_modify({'EMCC_WASM_BACKEND': '0'}):
-      self.check_working([EMCC] + MINIMAL_HELLO_WORLD, '')
-      self.assertExists(os.path.join(root_cache, 'asmjs'))
-      shutil.rmtree(os.path.join(root_cache, 'asmjs'))
-
-    self.check_working([EMCC] + MINIMAL_HELLO_WORLD, '')
-    self.assertExists(os.path.join(root_cache, 'asmjs'))
 
   def test_required_config_settings(self):
     # with no binaryen root, an error is shown
@@ -821,8 +701,6 @@ fi
     self.assertContained('generating system library', self.do([EMBUILDER, 'build', 'libemmalloc', '--force']))
 
   def test_embuilder_wasm_backend(self):
-    if not Settings.WASM_BACKEND:
-      self.skipTest('wasm backend only')
     restore_and_set_up()
     # the --lto flag makes us build wasm-bc
     self.do([EMCC, '--clear-cache'])
